@@ -60,37 +60,97 @@ unnest.tidyseurat_nested <- function(
   names_repair="check_unique", .drop, .id, .sep, .preserve
 ){
   
-  # Need this otherwise crashes map
-  .data_ = data
+
   
   cols <- enquo(cols)
 
+  unnest_seurat(data, !!cols, ..., keep_empty=keep_empty, ptype=ptype,
+                                names_sep=names_sep, names_repair=names_repair)
+
+}
+
+#' unnest_seurat
+#'
+#' @importFrom tidyr unnest
+#' @importFrom purrr when
+#' @importFrom rlang quo_name
+#' @importFrom purrr imap
+#'
+#' @param data A tbl. (See tidyr)
+#' @param cols <[`tidy-select`][tidyr_tidy_select]> Columns to unnest.
+#'   If you `unnest()` multiple columns, parallel entries must be of
+#'   compatible sizes, i.e. they're either equal or length 1 (following the
+#'   standard tidyverse recycling rules).
+#' @param ... <[`tidy-select`][tidyr_tidy_select]> Columns to nest, specified
+#'   using name-variable pairs of the form `new_col=c(col1, col2, col3)`.
+#'   The right hand side can be any valid tidy select expression.
+#'
+#' @param names_sep If `NULL`, the default, the names will be left
+#'   as is. In `nest()`, inner names will come from the former outer names;
+#'   in `unnest()`, the new outer names will come from the inner names.
+#'
+#'   If a string, the inner and outer names will be used together. In `nest()`,
+#'   the names of the new outer columns will be formed by pasting together the
+#'   outer and the inner column names, separated by `names_sep`. In `unnest()`,
+#'   the new inner names will have the outer names (+ `names_sep`) automatically
+#'   stripped. This makes `names_sep` roughly symmetric between nesting and unnesting.
+#' @param keep_empty See tidyr::unnest
+#' @param names_repair See tidyr::unnest
+#' @param ptype See tidyr::unnest
+#' @param .drop See tidyr::unnest
+#' @param .id tidyr::unnest
+#' @param .sep tidyr::unnest
+#' @param .preserve See tidyr::unnest
+#'
+#' @return A tidySingleCellExperiment objector a tibble depending on input
+#'
+#' @examples
+#'
+#' library(dplyr)
+#' pbmc_small %>%
+#'
+#'     nest(data=-groups) %>%
+#'     unnest_seurat(data)
+#'
+#' @rdname unnest_seurat
+#' @name unnest_seurat
+#'
+#'
+#'
+#' @export
+unnest_seurat  <-  function(data, cols, ..., keep_empty=FALSE, ptype=NULL,
+                                            names_sep=NULL, names_repair="check_unique", .drop, .id, .sep, .preserve) {
+  # Need this otherwise crashes map
+  .data_ <- data
+  
+  cols <- enquo(cols)
+  
   .data_ %>% 
     when(
       
       # If my only column to unnest is tidyseurat
       pull(., !!cols) %>% .[[1]] %>% is("Seurat") %>% any ~  
-      {
-        # Do my trick to unnest
-        list_seurat = 
-          mutate(., !!cols := imap(
-          !!cols, ~ .x %>%
-            bind_cols_(
-              
-              # Attach back the columns used for nesting
-              .data_ %>% select(-!!cols) %>% slice(rep(.y, nrow(as_tibble(.x))))
-            )
-        )) %>%
-        pull(!!cols) 
-        
-        list_seurat[[1]] %>%
+        {
+          # Do my trick to unnest
+          list_seurat = 
+            mutate(., !!cols := imap(
+              !!cols, ~ .x %>%
+                bind_cols_(
+                  
+                  # Attach back the columns used for nesting
+                  .data_ %>% select(-!!cols) %>% slice(rep(.y, nrow(as_tibble(.x))))
+                )
+            )) %>%
+            pull(!!cols) 
           
-          # Bind only if length list > 1
-          when(
-            length(list_seurat)>1 ~ bind_rows(., list_seurat[2:length(list_seurat)]),
-            ~ (.)
-          )
-      },
+          list_seurat[[1]] %>%
+            
+            # Bind only if length list > 1
+            when(
+              length(list_seurat)>1 ~ bind_rows(., list_seurat[2:length(list_seurat)]),
+              ~ (.)
+            )
+        },
       
       # Else do normal stuff
       ~ (.) %>% 
@@ -99,9 +159,9 @@ unnest.tidyseurat_nested <- function(
         add_class("tidyseurat_nested")
       
     )
-
 }
 
+
 #' nest
 #'
 #' @importFrom tidyr nest
